Opt

Struct Opt 

pub struct Opt {
    pub name: String,
    pub alt_name: String,
    pub short: String,
    pub value: String,
    pub def_val: String,
    pub set: bool,
}
Option values to consume flags:

  • -v or –verbose or –debug
  • -q or –quiet or –batch
  • -h or –help or –info
  • -V or –version : print version and exit

The value could be pass or default as well, e.g. –verbose=true or –verbose=false, but the presence of the flag itself is enough to set it to true (–verbose), and absence means false.

Fields

name: String

The name of the option

alt_name: String

The alternate long name of the option

short: Stringvalue: String

The value of the option

def_val: String

The default value of the option

set: bool

The value of the option was set

Implementations

Source

impl Opt

pub fn new(name: &str, alt_name: &str, short: &str, def_val: &str) -> Self

pub fn is_set(&self) -> bool

pub fn apply(&mut self, arg: &str) -> bool

Match and apply arg to this option. Returns true if the arg matched.