pub struct Opt {
pub name: String,
pub alt_name: String,
pub short: String,
pub value: String,
pub def_val: String,
pub set: bool,
}Expand description
Option values to consume flags:
- -v or –verbose or –debug
- -q or –quiet or –batch
- -h or –help or –info
- -V or –version : print version and exit
The value could be pass or default as well, e.g. –verbose=true or –verbose=false, but the presence of the flag itself is enough to set it to true (–verbose), and absence means false.
Fields
name: StringThe name of the option
alt_name: StringThe alternate long name of the option
short: Stringvalue: StringThe value of the option
def_val: StringThe default value of the option
set: boolThe value of the option was set
Implementations